@@ -1,6 +1,6 @@
 CREATE TABLE `issue_9` (
   `a` int(11) default NULL,
   `b` int(11) default NULL,
-  PRIMARY KEY  (`a`),
-  KEY `j` (`a`,`b`)
+  UNIQUE KEY `i` (`a`,`b`),
+  UNIQUE KEY `j` (`a`)
 ) ENGINE=MyISAM
